@@ -53,20 +53,12 @@ class AliyunRosStackProperties:
         :param tags: Values for ROS stack tags that should be passed when the stack is deployed. Default: - No tags
         '''
         if __debug__:
-            def stub(
-                *,
-                template_file: builtins.str,
-                parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                stack_name: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__50db4a4408e92654c48d87ed0677ec40f604c7be253310fca5ce2f70f07f8b10)
             check_type(argname="argument template_file", value=template_file, expected_type=type_hints["template_file"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
             check_type(argname="argument stack_name", value=stack_name, expected_type=type_hints["stack_name"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "template_file": template_file,
         }
         if parameters is not None:
@@ -149,20 +141,12 @@ class AmiContextQuery:
         :param owners: Owners to DescribeImages call. Default: - All owners
         '''
         if __debug__:
-            def stub(
-                *,
-                account: builtins.str,
-                filters: typing.Mapping[builtins.str, typing.Sequence[builtins.str]],
-                region: builtins.str,
-                owners: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4da5c94286713a25f11bbf84fc0fa807019391853bda290dd844c4f8f34e8978)
             check_type(argname="argument account", value=account, expected_type=type_hints["account"])
             check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument owners", value=owners, expected_type=type_hints["owners"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "account": account,
             "filters": filters,
             "region": region,
@@ -228,8 +212,8 @@ class ArtifactManifest:
         *,
         type: "ArtifactType",
         dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union["MetadataEntry", typing.Dict[str, typing.Any]]]]] = None,
-        properties: typing.Optional[typing.Union[typing.Union[AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union["TreeArtifactProperties", typing.Dict[str, typing.Any]], typing.Union["NestedCloudAssemblyProperties", typing.Dict[str, typing.Any]]]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union["MetadataEntry", typing.Dict[builtins.str, typing.Any]]]]] = None,
+        properties: typing.Optional[typing.Union[typing.Union[AliyunRosStackProperties, typing.Dict[builtins.str, typing.Any]], typing.Union["TreeArtifactProperties", typing.Dict[builtins.str, typing.Any]], typing.Union["NestedCloudAssemblyProperties", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''A manifest for a single artifact within the cloud assembly.
 
@@ -239,20 +223,12 @@ class ArtifactManifest:
         :param properties: The set of properties for this artifact (depends on type). Default: - no properties.
         '''
         if __debug__:
-            def stub(
-                *,
-                type: "ArtifactType",
-                dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-                metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union["MetadataEntry", typing.Dict[str, typing.Any]]]]] = None,
-                properties: typing.Optional[typing.Union[typing.Union[AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union["TreeArtifactProperties", typing.Dict[str, typing.Any]], typing.Union["NestedCloudAssemblyProperties", typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b23c064aa8a7a12940601a4c031f5909112530123fae3b281b473992e6c98422)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument dependencies", value=dependencies, expected_type=type_hints["dependencies"])
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
             check_type(argname="argument properties", value=properties, expected_type=type_hints["properties"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "type": type,
         }
         if dependencies is not None:
@@ -359,9 +335,9 @@ class AssemblyManifest:
         self,
         *,
         version: builtins.str,
-        artifacts: typing.Optional[typing.Mapping[builtins.str, typing.Union[ArtifactManifest, typing.Dict[str, typing.Any]]]] = None,
-        missing: typing.Optional[typing.Sequence[typing.Union["MissingContext", typing.Dict[str, typing.Any]]]] = None,
-        runtime: typing.Optional[typing.Union["RuntimeInfo", typing.Dict[str, typing.Any]]] = None,
+        artifacts: typing.Optional[typing.Mapping[builtins.str, typing.Union[ArtifactManifest, typing.Dict[builtins.str, typing.Any]]]] = None,
+        missing: typing.Optional[typing.Sequence[typing.Union["MissingContext", typing.Dict[builtins.str, typing.Any]]]] = None,
+        runtime: typing.Optional[typing.Union["RuntimeInfo", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''A manifest which describes the cloud assembly.
 
@@ -373,20 +349,12 @@ class AssemblyManifest:
         if isinstance(runtime, dict):
             runtime = RuntimeInfo(**runtime)
         if __debug__:
-            def stub(
-                *,
-                version: builtins.str,
-                artifacts: typing.Optional[typing.Mapping[builtins.str, typing.Union[ArtifactManifest, typing.Dict[str, typing.Any]]]] = None,
-                missing: typing.Optional[typing.Sequence[typing.Union["MissingContext", typing.Dict[str, typing.Any]]]] = None,
-                runtime: typing.Optional[typing.Union["RuntimeInfo", typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b6b194e83c34230d0742619fe13b220ec6ccf3e707ed53bb1f8153e7fa375a5f)
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
             check_type(argname="argument artifacts", value=artifacts, expected_type=type_hints["artifacts"])
             check_type(argname="argument missing", value=missing, expected_type=type_hints["missing"])
             check_type(argname="argument runtime", value=runtime, expected_type=type_hints["runtime"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "version": version,
         }
         if artifacts is not None:
@@ -460,12 +428,10 @@ class AvailabilityZonesContextQuery:
         :param region: Query region.
         '''
         if __debug__:
-            def stub(*, account: builtins.str, region: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__85e5f6837358a10c72d3f9dd17a950563028b27c1bf2cd274fb3941b7a77f604)
             check_type(argname="argument account", value=account, expected_type=type_hints["account"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "account": account,
             "region": region,
         }
@@ -538,18 +504,11 @@ class EndpointServiceAvailabilityZonesContextQuery:
         :param service_name: Query service name.
         '''
         if __debug__:
-            def stub(
-                *,
-                account: builtins.str,
-                region: builtins.str,
-                service_name: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a078309ccccfdfd1ee77a351debeb8fe6685655ce70244eee67dc0e18b60914d)
             check_type(argname="argument account", value=account, expected_type=type_hints["account"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument service_name", value=service_name, expected_type=type_hints["service_name"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "account": account,
             "region": region,
             "service_name": service_name,
@@ -618,22 +577,13 @@ class HostedZoneContextQuery:
         :param vpc_id: The VPC ID to that the private zone must be associated with. If you provide VPC ID and privateZone is false, this will return no results and raise an error. Default: - Required if privateZone=true
         '''
         if __debug__:
-            def stub(
-                *,
-                account: builtins.str,
-                domain_name: builtins.str,
-                region: builtins.str,
-                private_zone: typing.Optional[builtins.bool] = None,
-                vpc_id: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__04d17b4b9ff55746c3bcd55def770548977d06817af547bba2a854fa19f03584)
             check_type(argname="argument account", value=account, expected_type=type_hints["account"])
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument private_zone", value=private_zone, expected_type=type_hints["private_zone"])
             check_type(argname="argument vpc_id", value=vpc_id, expected_type=type_hints["vpc_id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "account": account,
             "domain_name": domain_name,
             "region": region,
@@ -715,9 +665,7 @@ class Manifest(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(file_path: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4420e1fb15ea773f97ce770a8940f33e8c3711b7430b0840422e0f5ab6ec6643)
             check_type(argname="argument file_path", value=file_path, expected_type=type_hints["file_path"])
         return typing.cast(AssemblyManifest, jsii.sinvoke(cls, "load", [file_path]))
 
@@ -729,9 +677,7 @@ class Manifest(
         :param file_path: - path to the manifest file.
         '''
         if __debug__:
-            def stub(file_path: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__17c1b7476293f37e48eba72cfcad6b50e4f15bb6b2241cb555a0c48e55f9e946)
             check_type(argname="argument file_path", value=file_path, expected_type=type_hints["file_path"])
         return typing.cast(AssemblyManifest, jsii.sinvoke(cls, "loadAssemblyManifest", [file_path]))
 
@@ -739,7 +685,7 @@ class Manifest(
     @builtins.classmethod
     def save(
         cls,
-        manifest: typing.Union[AssemblyManifest, typing.Dict[str, typing.Any]],
+        manifest: typing.Union[AssemblyManifest, typing.Dict[builtins.str, typing.Any]],
         file_path: builtins.str,
     ) -> None:
         '''(deprecated) Deprecated.
@@ -752,12 +698,7 @@ class Manifest(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(
-                manifest: typing.Union[AssemblyManifest, typing.Dict[str, typing.Any]],
-                file_path: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__dd1fca2945793b04838a4a50a2995f16fc16a14004ac3e439e3718ee76d660b1)
             check_type(argname="argument manifest", value=manifest, expected_type=type_hints["manifest"])
             check_type(argname="argument file_path", value=file_path, expected_type=type_hints["file_path"])
         return typing.cast(None, jsii.sinvoke(cls, "save", [manifest, file_path]))
@@ -766,7 +707,7 @@ class Manifest(
     @builtins.classmethod
     def save_assembly_manifest(
         cls,
-        manifest: typing.Union[AssemblyManifest, typing.Dict[str, typing.Any]],
+        manifest: typing.Union[AssemblyManifest, typing.Dict[builtins.str, typing.Any]],
         file_path: builtins.str,
     ) -> None:
         '''Validates and saves the cloud assembly manifest to file.
@@ -775,12 +716,7 @@ class Manifest(
         :param file_path: - output file path.
         '''
         if __debug__:
-            def stub(
-                manifest: typing.Union[AssemblyManifest, typing.Dict[str, typing.Any]],
-                file_path: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1b07952bceb7b5dbdad81bfbf6b876483f428fb8e4cc90dacd947272038ed2ef)
             check_type(argname="argument manifest", value=manifest, expected_type=type_hints["manifest"])
             check_type(argname="argument file_path", value=file_path, expected_type=type_hints["file_path"])
         return typing.cast(None, jsii.sinvoke(cls, "saveAssemblyManifest", [manifest, file_path]))
@@ -802,7 +738,7 @@ class MetadataEntry:
         self,
         *,
         type: builtins.str,
-        data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union["Tag", typing.Dict[str, typing.Any]]]]] = None,
+        data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union["Tag", typing.Dict[builtins.str, typing.Any]]]]] = None,
         trace: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''A metadata entry in a cloud assembly artifact.
@@ -812,18 +748,11 @@ class MetadataEntry:
         :param trace: A stack trace for when the entry was created. Default: - no trace.
         '''
         if __debug__:
-            def stub(
-                *,
-                type: builtins.str,
-                data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union["Tag", typing.Dict[str, typing.Any]]]]] = None,
-                trace: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3019f66821df35df8528c8c05491120941f8ea312aac91790b449549012331d1)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument data", value=data, expected_type=type_hints["data"])
             check_type(argname="argument trace", value=trace, expected_type=type_hints["trace"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "type": type,
         }
         if data is not None:
@@ -878,7 +807,7 @@ class MissingContext:
         self,
         *,
         key: builtins.str,
-        props: typing.Union[typing.Union[AmiContextQuery, typing.Dict[str, typing.Any]], typing.Union[AvailabilityZonesContextQuery, typing.Dict[str, typing.Any]], typing.Union[HostedZoneContextQuery, typing.Dict[str, typing.Any]], typing.Union["SSMParameterContextQuery", typing.Dict[str, typing.Any]], typing.Union["VpcContextQuery", typing.Dict[str, typing.Any]], typing.Union[EndpointServiceAvailabilityZonesContextQuery, typing.Dict[str, typing.Any]]],
+        props: typing.Union[typing.Union[AmiContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union[AvailabilityZonesContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union[HostedZoneContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union["SSMParameterContextQuery", typing.Dict[builtins.str, typing.Any]], typing.Union["VpcContextQuery", typing.Dict[builtins.str, typing.Any]], typing.Union[EndpointServiceAvailabilityZonesContextQuery, typing.Dict[builtins.str, typing.Any]]],
         provider: ContextProvider,
     ) -> None:
         '''Represents a missing piece of context.
@@ -888,18 +817,11 @@ class MissingContext:
         :param provider: The provider from which we expect this context key to be obtained.
         '''
         if __debug__:
-            def stub(
-                *,
-                key: builtins.str,
-                props: typing.Union[typing.Union[AmiContextQuery, typing.Dict[str, typing.Any]], typing.Union[AvailabilityZonesContextQuery, typing.Dict[str, typing.Any]], typing.Union[HostedZoneContextQuery, typing.Dict[str, typing.Any]], typing.Union["SSMParameterContextQuery", typing.Dict[str, typing.Any]], typing.Union["VpcContextQuery", typing.Dict[str, typing.Any]], typing.Union[EndpointServiceAvailabilityZonesContextQuery, typing.Dict[str, typing.Any]]],
-                provider: ContextProvider,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd208c8ef5bda641b030f2924e2a6961d665850446cf2b575436ba665db0842a)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
             check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "key": key,
             "props": props,
             "provider": provider,
@@ -958,16 +880,10 @@ class NestedCloudAssemblyProperties:
         :param display_name: Display name for the cloud assembly. Default: - The artifact ID
         '''
         if __debug__:
-            def stub(
-                *,
-                directory_name: builtins.str,
-                display_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bfa16176adeadd12b83b59121710d14bc1c3b6815c3542e63501e57721b229ce)
             check_type(argname="argument directory_name", value=directory_name, expected_type=type_hints["directory_name"])
             check_type(argname="argument display_name", value=display_name, expected_type=type_hints["display_name"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "directory_name": directory_name,
         }
         if display_name is not None:
@@ -1017,11 +933,9 @@ class RuntimeInfo:
         :param libraries: The list of libraries loaded in the application, associated with their versions.
         '''
         if __debug__:
-            def stub(*, libraries: typing.Mapping[builtins.str, builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b9c8536bbfca4e3700cf843c7f2382568dd7ce259dbe2cbd93e61074e87ab48f)
             check_type(argname="argument libraries", value=libraries, expected_type=type_hints["libraries"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "libraries": libraries,
         }
 
@@ -1068,18 +982,11 @@ class SSMParameterContextQuery:
         :param region: Query region.
         '''
         if __debug__:
-            def stub(
-                *,
-                account: builtins.str,
-                parameter_name: builtins.str,
-                region: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__67b5a36a6922de48a7b300011d383adbc506ec15c6bb7cd6aec32e3614f52477)
             check_type(argname="argument account", value=account, expected_type=type_hints["account"])
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "account": account,
             "parameter_name": parameter_name,
             "region": region,
@@ -1131,12 +1038,10 @@ class Tag:
         :param value: Tag value.
         '''
         if __debug__:
-            def stub(*, key: builtins.str, value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a29ec2f54aa330d0f09779198bd6fb009ae14982497dcd42a9093f160c08173d)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "key": key,
             "value": value,
         }
@@ -1179,11 +1084,9 @@ class TreeArtifactProperties:
         :param file: Filename of the tree artifact.
         '''
         if __debug__:
-            def stub(*, file: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c9b3874b02e6b59d07063e4307b8e38df0808c88c5a641829f794e1ceede1933)
             check_type(argname="argument file", value=file, expected_type=type_hints["file"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "file": file,
         }
 
@@ -1236,22 +1139,13 @@ class VpcContextQuery:
         :param subnet_group_name_tag: Optional tag for subnet group name. If not provided, we'll look at the ros-cdk:subnet-name tag. If the subnet does not have the specified tag, we'll use its type as the name. Default: 'ros-cdk:subnet-name'
         '''
         if __debug__:
-            def stub(
-                *,
-                account: builtins.str,
-                filter: typing.Mapping[builtins.str, builtins.str],
-                region: builtins.str,
-                return_asymmetric_subnets: typing.Optional[builtins.bool] = None,
-                subnet_group_name_tag: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ecf79a3d9511e8c24f1f7fb3852689dd1fbf7976dcee2b048887b0491a8d7994)
             check_type(argname="argument account", value=account, expected_type=type_hints["account"])
             check_type(argname="argument filter", value=filter, expected_type=type_hints["filter"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument return_asymmetric_subnets", value=return_asymmetric_subnets, expected_type=type_hints["return_asymmetric_subnets"])
             check_type(argname="argument subnet_group_name_tag", value=subnet_group_name_tag, expected_type=type_hints["subnet_group_name_tag"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "account": account,
             "filter": filter,
             "region": region,
@@ -1342,3 +1236,165 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__50db4a4408e92654c48d87ed0677ec40f604c7be253310fca5ce2f70f07f8b10(
+    *,
+    template_file: builtins.str,
+    parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    stack_name: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4da5c94286713a25f11bbf84fc0fa807019391853bda290dd844c4f8f34e8978(
+    *,
+    account: builtins.str,
+    filters: typing.Mapping[builtins.str, typing.Sequence[builtins.str]],
+    region: builtins.str,
+    owners: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b23c064aa8a7a12940601a4c031f5909112530123fae3b281b473992e6c98422(
+    *,
+    type: ArtifactType,
+    dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+    metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[MetadataEntry, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    properties: typing.Optional[typing.Union[typing.Union[AliyunRosStackProperties, typing.Dict[builtins.str, typing.Any]], typing.Union[TreeArtifactProperties, typing.Dict[builtins.str, typing.Any]], typing.Union[NestedCloudAssemblyProperties, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b6b194e83c34230d0742619fe13b220ec6ccf3e707ed53bb1f8153e7fa375a5f(
+    *,
+    version: builtins.str,
+    artifacts: typing.Optional[typing.Mapping[builtins.str, typing.Union[ArtifactManifest, typing.Dict[builtins.str, typing.Any]]]] = None,
+    missing: typing.Optional[typing.Sequence[typing.Union[MissingContext, typing.Dict[builtins.str, typing.Any]]]] = None,
+    runtime: typing.Optional[typing.Union[RuntimeInfo, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__85e5f6837358a10c72d3f9dd17a950563028b27c1bf2cd274fb3941b7a77f604(
+    *,
+    account: builtins.str,
+    region: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a078309ccccfdfd1ee77a351debeb8fe6685655ce70244eee67dc0e18b60914d(
+    *,
+    account: builtins.str,
+    region: builtins.str,
+    service_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__04d17b4b9ff55746c3bcd55def770548977d06817af547bba2a854fa19f03584(
+    *,
+    account: builtins.str,
+    domain_name: builtins.str,
+    region: builtins.str,
+    private_zone: typing.Optional[builtins.bool] = None,
+    vpc_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4420e1fb15ea773f97ce770a8940f33e8c3711b7430b0840422e0f5ab6ec6643(
+    file_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17c1b7476293f37e48eba72cfcad6b50e4f15bb6b2241cb555a0c48e55f9e946(
+    file_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dd1fca2945793b04838a4a50a2995f16fc16a14004ac3e439e3718ee76d660b1(
+    manifest: typing.Union[AssemblyManifest, typing.Dict[builtins.str, typing.Any]],
+    file_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1b07952bceb7b5dbdad81bfbf6b876483f428fb8e4cc90dacd947272038ed2ef(
+    manifest: typing.Union[AssemblyManifest, typing.Dict[builtins.str, typing.Any]],
+    file_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3019f66821df35df8528c8c05491120941f8ea312aac91790b449549012331d1(
+    *,
+    type: builtins.str,
+    data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union[Tag, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    trace: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cd208c8ef5bda641b030f2924e2a6961d665850446cf2b575436ba665db0842a(
+    *,
+    key: builtins.str,
+    props: typing.Union[typing.Union[AmiContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union[AvailabilityZonesContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union[HostedZoneContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union[SSMParameterContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union[VpcContextQuery, typing.Dict[builtins.str, typing.Any]], typing.Union[EndpointServiceAvailabilityZonesContextQuery, typing.Dict[builtins.str, typing.Any]]],
+    provider: ContextProvider,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bfa16176adeadd12b83b59121710d14bc1c3b6815c3542e63501e57721b229ce(
+    *,
+    directory_name: builtins.str,
+    display_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b9c8536bbfca4e3700cf843c7f2382568dd7ce259dbe2cbd93e61074e87ab48f(
+    *,
+    libraries: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__67b5a36a6922de48a7b300011d383adbc506ec15c6bb7cd6aec32e3614f52477(
+    *,
+    account: builtins.str,
+    parameter_name: builtins.str,
+    region: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a29ec2f54aa330d0f09779198bd6fb009ae14982497dcd42a9093f160c08173d(
+    *,
+    key: builtins.str,
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c9b3874b02e6b59d07063e4307b8e38df0808c88c5a641829f794e1ceede1933(
+    *,
+    file: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ecf79a3d9511e8c24f1f7fb3852689dd1fbf7976dcee2b048887b0491a8d7994(
+    *,
+    account: builtins.str,
+    filter: typing.Mapping[builtins.str, builtins.str],
+    region: builtins.str,
+    return_asymmetric_subnets: typing.Optional[builtins.bool] = None,
+    subnet_group_name_tag: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
